@@ -33,7 +33,7 @@ namespace Model
   class StatefulEngineOptions
   {
   public:
-    AWS_FMS_API StatefulEngineOptions();
+    AWS_FMS_API StatefulEngineOptions() = default;
     AWS_FMS_API StatefulEngineOptions(Aws::Utils::Json::JsonView jsonValue);
     AWS_FMS_API StatefulEngineOptions& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_FMS_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -49,12 +49,10 @@ namespace Model
      * order for stateful rules</a> in the <i>Network Firewall Developer Guide</i>.</p>
      * <p>Default: <code>DEFAULT_ACTION_ORDER</code> </p>
      */
-    inline const RuleOrder& GetRuleOrder() const{ return m_ruleOrder; }
+    inline RuleOrder GetRuleOrder() const { return m_ruleOrder; }
     inline bool RuleOrderHasBeenSet() const { return m_ruleOrderHasBeenSet; }
-    inline void SetRuleOrder(const RuleOrder& value) { m_ruleOrderHasBeenSet = true; m_ruleOrder = value; }
-    inline void SetRuleOrder(RuleOrder&& value) { m_ruleOrderHasBeenSet = true; m_ruleOrder = std::move(value); }
-    inline StatefulEngineOptions& WithRuleOrder(const RuleOrder& value) { SetRuleOrder(value); return *this;}
-    inline StatefulEngineOptions& WithRuleOrder(RuleOrder&& value) { SetRuleOrder(std::move(value)); return *this;}
+    inline void SetRuleOrder(RuleOrder value) { m_ruleOrderHasBeenSet = true; m_ruleOrder = value; }
+    inline StatefulEngineOptions& WithRuleOrder(RuleOrder value) { SetRuleOrder(value); return *this;}
     ///@}
 
     ///@{
@@ -83,19 +81,17 @@ namespace Model
      * exception policy in your firewall policy</a> in the <i>Network Firewall
      * Developer Guide</i>.</p> <p>Default: <code>FMS_IGNORE</code> </p>
      */
-    inline const StreamExceptionPolicy& GetStreamExceptionPolicy() const{ return m_streamExceptionPolicy; }
+    inline StreamExceptionPolicy GetStreamExceptionPolicy() const { return m_streamExceptionPolicy; }
     inline bool StreamExceptionPolicyHasBeenSet() const { return m_streamExceptionPolicyHasBeenSet; }
-    inline void SetStreamExceptionPolicy(const StreamExceptionPolicy& value) { m_streamExceptionPolicyHasBeenSet = true; m_streamExceptionPolicy = value; }
-    inline void SetStreamExceptionPolicy(StreamExceptionPolicy&& value) { m_streamExceptionPolicyHasBeenSet = true; m_streamExceptionPolicy = std::move(value); }
-    inline StatefulEngineOptions& WithStreamExceptionPolicy(const StreamExceptionPolicy& value) { SetStreamExceptionPolicy(value); return *this;}
-    inline StatefulEngineOptions& WithStreamExceptionPolicy(StreamExceptionPolicy&& value) { SetStreamExceptionPolicy(std::move(value)); return *this;}
+    inline void SetStreamExceptionPolicy(StreamExceptionPolicy value) { m_streamExceptionPolicyHasBeenSet = true; m_streamExceptionPolicy = value; }
+    inline StatefulEngineOptions& WithStreamExceptionPolicy(StreamExceptionPolicy value) { SetStreamExceptionPolicy(value); return *this;}
     ///@}
   private:
 
-    RuleOrder m_ruleOrder;
+    RuleOrder m_ruleOrder{RuleOrder::NOT_SET};
     bool m_ruleOrderHasBeenSet = false;
 
-    StreamExceptionPolicy m_streamExceptionPolicy;
+    StreamExceptionPolicy m_streamExceptionPolicy{StreamExceptionPolicy::NOT_SET};
     bool m_streamExceptionPolicyHasBeenSet = false;
   };
 
