@@ -30,7 +30,7 @@ namespace Model
   class BinaryColumnStatisticsData
   {
   public:
-    AWS_GLUE_API BinaryColumnStatisticsData();
+    AWS_GLUE_API BinaryColumnStatisticsData() = default;
     AWS_GLUE_API BinaryColumnStatisticsData(Aws::Utils::Json::JsonView jsonValue);
     AWS_GLUE_API BinaryColumnStatisticsData& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_GLUE_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -40,7 +40,7 @@ namespace Model
     /**
      * <p>The size of the longest bit sequence in the column.</p>
      */
-    inline long long GetMaximumLength() const{ return m_maximumLength; }
+    inline long long GetMaximumLength() const { return m_maximumLength; }
     inline bool MaximumLengthHasBeenSet() const { return m_maximumLengthHasBeenSet; }
     inline void SetMaximumLength(long long value) { m_maximumLengthHasBeenSet = true; m_maximumLength = value; }
     inline BinaryColumnStatisticsData& WithMaximumLength(long long value) { SetMaximumLength(value); return *this;}
@@ -50,7 +50,7 @@ namespace Model
     /**
      * <p>The average bit sequence length in the column.</p>
      */
-    inline double GetAverageLength() const{ return m_averageLength; }
+    inline double GetAverageLength() const { return m_averageLength; }
     inline bool AverageLengthHasBeenSet() const { return m_averageLengthHasBeenSet; }
     inline void SetAverageLength(double value) { m_averageLengthHasBeenSet = true; m_averageLength = value; }
     inline BinaryColumnStatisticsData& WithAverageLength(double value) { SetAverageLength(value); return *this;}
@@ -60,20 +60,20 @@ namespace Model
     /**
      * <p>The number of null values in the column.</p>
      */
-    inline long long GetNumberOfNulls() const{ return m_numberOfNulls; }
+    inline long long GetNumberOfNulls() const { return m_numberOfNulls; }
     inline bool NumberOfNullsHasBeenSet() const { return m_numberOfNullsHasBeenSet; }
     inline void SetNumberOfNulls(long long value) { m_numberOfNullsHasBeenSet = true; m_numberOfNulls = value; }
     inline BinaryColumnStatisticsData& WithNumberOfNulls(long long value) { SetNumberOfNulls(value); return *this;}
     ///@}
   private:
 
-    long long m_maximumLength;
+    long long m_maximumLength{0};
     bool m_maximumLengthHasBeenSet = false;
 
-    double m_averageLength;
+    double m_averageLength{0.0};
     bool m_averageLengthHasBeenSet = false;
 
-    long long m_numberOfNulls;
+    long long m_numberOfNulls{0};
     bool m_numberOfNullsHasBeenSet = false;
   };
 
