@@ -34,7 +34,7 @@ namespace Model
   class DestinationConfiguration
   {
   public:
-    AWS_IVS_API DestinationConfiguration();
+    AWS_IVS_API DestinationConfiguration() = default;
     AWS_IVS_API DestinationConfiguration(Aws::Utils::Json::JsonView jsonValue);
     AWS_IVS_API DestinationConfiguration& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_IVS_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -44,12 +44,12 @@ namespace Model
     /**
      * <p>An S3 destination configuration where recorded videos will be stored.</p>
      */
-    inline const S3DestinationConfiguration& GetS3() const{ return m_s3; }
+    inline const S3DestinationConfiguration& GetS3() const { return m_s3; }
     inline bool S3HasBeenSet() const { return m_s3HasBeenSet; }
-    inline void SetS3(const S3DestinationConfiguration& value) { m_s3HasBeenSet = true; m_s3 = value; }
-    inline void SetS3(S3DestinationConfiguration&& value) { m_s3HasBeenSet = true; m_s3 = std::move(value); }
-    inline DestinationConfiguration& WithS3(const S3DestinationConfiguration& value) { SetS3(value); return *this;}
-    inline DestinationConfiguration& WithS3(S3DestinationConfiguration&& value) { SetS3(std::move(value)); return *this;}
+    template<typename S3T = S3DestinationConfiguration>
+    void SetS3(S3T&& value) { m_s3HasBeenSet = true; m_s3 = std::forward<S3T>(value); }
+    template<typename S3T = S3DestinationConfiguration>
+    DestinationConfiguration& WithS3(S3T&& value) { SetS3(std::forward<S3T>(value)); return *this;}
     ///@}
   private:
 
