@@ -32,7 +32,7 @@ namespace Model
   class InputContext
   {
   public:
-    AWS_LEXMODELSV2_API InputContext();
+    AWS_LEXMODELSV2_API InputContext() = default;
     AWS_LEXMODELSV2_API InputContext(Aws::Utils::Json::JsonView jsonValue);
     AWS_LEXMODELSV2_API InputContext& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_LEXMODELSV2_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -42,14 +42,12 @@ namespace Model
     /**
      * <p>The name of the context.</p>
      */
-    inline const Aws::String& GetName() const{ return m_name; }
+    inline const Aws::String& GetName() const { return m_name; }
     inline bool NameHasBeenSet() const { return m_nameHasBeenSet; }
-    inline void SetName(const Aws::String& value) { m_nameHasBeenSet = true; m_name = value; }
-    inline void SetName(Aws::String&& value) { m_nameHasBeenSet = true; m_name = std::move(value); }
-    inline void SetName(const char* value) { m_nameHasBeenSet = true; m_name.assign(value); }
-    inline InputContext& WithName(const Aws::String& value) { SetName(value); return *this;}
-    inline InputContext& WithName(Aws::String&& value) { SetName(std::move(value)); return *this;}
-    inline InputContext& WithName(const char* value) { SetName(value); return *this;}
+    template<typename NameT = Aws::String>
+    void SetName(NameT&& value) { m_nameHasBeenSet = true; m_name = std::forward<NameT>(value); }
+    template<typename NameT = Aws::String>
+    InputContext& WithName(NameT&& value) { SetName(std::forward<NameT>(value)); return *this;}
     ///@}
   private:
 
