@@ -43,7 +43,7 @@ namespace Model
   class RuleGroup
   {
   public:
-    AWS_NETWORKFIREWALL_API RuleGroup();
+    AWS_NETWORKFIREWALL_API RuleGroup() = default;
     AWS_NETWORKFIREWALL_API RuleGroup(Aws::Utils::Json::JsonView jsonValue);
     AWS_NETWORKFIREWALL_API RuleGroup& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_NETWORKFIREWALL_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -54,36 +54,36 @@ namespace Model
      * <p>Settings that are available for use in the rules in the rule group. You can
      * only use these for stateful rule groups. </p>
      */
-    inline const RuleVariables& GetRuleVariables() const{ return m_ruleVariables; }
+    inline const RuleVariables& GetRuleVariables() const { return m_ruleVariables; }
     inline bool RuleVariablesHasBeenSet() const { return m_ruleVariablesHasBeenSet; }
-    inline void SetRuleVariables(const RuleVariables& value) { m_ruleVariablesHasBeenSet = true; m_ruleVariables = value; }
-    inline void SetRuleVariables(RuleVariables&& value) { m_ruleVariablesHasBeenSet = true; m_ruleVariables = std::move(value); }
-    inline RuleGroup& WithRuleVariables(const RuleVariables& value) { SetRuleVariables(value); return *this;}
-    inline RuleGroup& WithRuleVariables(RuleVariables&& value) { SetRuleVariables(std::move(value)); return *this;}
+    template<typename RuleVariablesT = RuleVariables>
+    void SetRuleVariables(RuleVariablesT&& value) { m_ruleVariablesHasBeenSet = true; m_ruleVariables = std::forward<RuleVariablesT>(value); }
+    template<typename RuleVariablesT = RuleVariables>
+    RuleGroup& WithRuleVariables(RuleVariablesT&& value) { SetRuleVariables(std::forward<RuleVariablesT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The list of a rule group's reference sets.</p>
      */
-    inline const ReferenceSets& GetReferenceSets() const{ return m_referenceSets; }
+    inline const ReferenceSets& GetReferenceSets() const { return m_referenceSets; }
     inline bool ReferenceSetsHasBeenSet() const { return m_referenceSetsHasBeenSet; }
-    inline void SetReferenceSets(const ReferenceSets& value) { m_referenceSetsHasBeenSet = true; m_referenceSets = value; }
-    inline void SetReferenceSets(ReferenceSets&& value) { m_referenceSetsHasBeenSet = true; m_referenceSets = std::move(value); }
-    inline RuleGroup& WithReferenceSets(const ReferenceSets& value) { SetReferenceSets(value); return *this;}
-    inline RuleGroup& WithReferenceSets(ReferenceSets&& value) { SetReferenceSets(std::move(value)); return *this;}
+    template<typename ReferenceSetsT = ReferenceSets>
+    void SetReferenceSets(ReferenceSetsT&& value) { m_referenceSetsHasBeenSet = true; m_referenceSets = std::forward<ReferenceSetsT>(value); }
+    template<typename ReferenceSetsT = ReferenceSets>
+    RuleGroup& WithReferenceSets(ReferenceSetsT&& value) { SetReferenceSets(std::forward<ReferenceSetsT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The stateful rules or stateless rules for the rule group. </p>
      */
-    inline const RulesSource& GetRulesSource() const{ return m_rulesSource; }
+    inline const RulesSource& GetRulesSource() const { return m_rulesSource; }
     inline bool RulesSourceHasBeenSet() const { return m_rulesSourceHasBeenSet; }
-    inline void SetRulesSource(const RulesSource& value) { m_rulesSourceHasBeenSet = true; m_rulesSource = value; }
-    inline void SetRulesSource(RulesSource&& value) { m_rulesSourceHasBeenSet = true; m_rulesSource = std::move(value); }
-    inline RuleGroup& WithRulesSource(const RulesSource& value) { SetRulesSource(value); return *this;}
-    inline RuleGroup& WithRulesSource(RulesSource&& value) { SetRulesSource(std::move(value)); return *this;}
+    template<typename RulesSourceT = RulesSource>
+    void SetRulesSource(RulesSourceT&& value) { m_rulesSourceHasBeenSet = true; m_rulesSource = std::forward<RulesSourceT>(value); }
+    template<typename RulesSourceT = RulesSource>
+    RuleGroup& WithRulesSource(RulesSourceT&& value) { SetRulesSource(std::forward<RulesSourceT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -95,12 +95,12 @@ namespace Model
      * href="https://docs.aws.amazon.com/network-firewall/latest/developerguide/suricata-limitations-caveats.html">Strict
      * evaluation order</a> in the <i>Network Firewall Developer Guide</i>.</p>
      */
-    inline const StatefulRuleOptions& GetStatefulRuleOptions() const{ return m_statefulRuleOptions; }
+    inline const StatefulRuleOptions& GetStatefulRuleOptions() const { return m_statefulRuleOptions; }
     inline bool StatefulRuleOptionsHasBeenSet() const { return m_statefulRuleOptionsHasBeenSet; }
-    inline void SetStatefulRuleOptions(const StatefulRuleOptions& value) { m_statefulRuleOptionsHasBeenSet = true; m_statefulRuleOptions = value; }
-    inline void SetStatefulRuleOptions(StatefulRuleOptions&& value) { m_statefulRuleOptionsHasBeenSet = true; m_statefulRuleOptions = std::move(value); }
-    inline RuleGroup& WithStatefulRuleOptions(const StatefulRuleOptions& value) { SetStatefulRuleOptions(value); return *this;}
-    inline RuleGroup& WithStatefulRuleOptions(StatefulRuleOptions&& value) { SetStatefulRuleOptions(std::move(value)); return *this;}
+    template<typename StatefulRuleOptionsT = StatefulRuleOptions>
+    void SetStatefulRuleOptions(StatefulRuleOptionsT&& value) { m_statefulRuleOptionsHasBeenSet = true; m_statefulRuleOptions = std::forward<StatefulRuleOptionsT>(value); }
+    template<typename StatefulRuleOptionsT = StatefulRuleOptions>
+    RuleGroup& WithStatefulRuleOptions(StatefulRuleOptionsT&& value) { SetStatefulRuleOptions(std::forward<StatefulRuleOptionsT>(value)); return *this;}
     ///@}
   private:
 
