@@ -7,6 +7,7 @@
 #include <aws/opsworkscm/OpsWorksCM_EXPORTS.h>
 #include <aws/core/client/ClientConfiguration.h>
 #include <aws/core/client/AWSClient.h>
+#include <aws/core/client/AWSClientAsyncCRTP.h>
 #include <aws/core/utils/json/JsonSerializer.h>
 #include <aws/opsworkscm/OpsWorksCMServiceClientModel.h>
 
@@ -58,34 +59,64 @@ namespace OpsWorksCM
    * <b>Throttling limits</b> </p> <p>All API operations allow for five requests per
    * second with a burst of 10 requests per second.</p>
    */
-  class AWS_OPSWORKSCM_API OpsWorksCMClient : public Aws::Client::AWSJsonClient
+  class AWS_OPSWORKSCM_API OpsWorksCMClient : public Aws::Client::AWSJsonClient, public Aws::Client::ClientWithAsyncTemplateMethods<OpsWorksCMClient>
   {
     public:
       typedef Aws::Client::AWSJsonClient BASECLASS;
+      static const char* GetServiceName();
+      static const char* GetAllocationTag();
+
+      typedef OpsWorksCMClientConfiguration ClientConfigurationType;
+      typedef OpsWorksCMEndpointProvider EndpointProviderType;
 
        /**
         * Initializes client to use DefaultCredentialProviderChain, with default http client factory, and optional client config. If client config
         * is not specified, it will be initialized to default values.
         */
-        OpsWorksCMClient(const Aws::Client::ClientConfiguration& clientConfiguration = Aws::Client::ClientConfiguration());
+        OpsWorksCMClient(const Aws::OpsWorksCM::OpsWorksCMClientConfiguration& clientConfiguration = Aws::OpsWorksCM::OpsWorksCMClientConfiguration(),
+                         std::shared_ptr<OpsWorksCMEndpointProviderBase> endpointProvider = nullptr);
 
        /**
         * Initializes client to use SimpleAWSCredentialsProvider, with default http client factory, and optional client config. If client config
         * is not specified, it will be initialized to default values.
         */
         OpsWorksCMClient(const Aws::Auth::AWSCredentials& credentials,
-                         const Aws::Client::ClientConfiguration& clientConfiguration = Aws::Client::ClientConfiguration());
+                         std::shared_ptr<OpsWorksCMEndpointProviderBase> endpointProvider = nullptr,
+                         const Aws::OpsWorksCM::OpsWorksCMClientConfiguration& clientConfiguration = Aws::OpsWorksCM::OpsWorksCMClientConfiguration());
 
        /**
         * Initializes client to use specified credentials provider with specified client config. If http client factory is not supplied,
         * the default http client factory will be used
         */
         OpsWorksCMClient(const std::shared_ptr<Aws::Auth::AWSCredentialsProvider>& credentialsProvider,
-                         const Aws::Client::ClientConfiguration& clientConfiguration = Aws::Client::ClientConfiguration());
+                         std::shared_ptr<OpsWorksCMEndpointProviderBase> endpointProvider = nullptr,
+                         const Aws::OpsWorksCM::OpsWorksCMClientConfiguration& clientConfiguration = Aws::OpsWorksCM::OpsWorksCMClientConfiguration());
 
+
+        /* Legacy constructors due deprecation */
+       /**
+        * Initializes client to use DefaultCredentialProviderChain, with default http client factory, and optional client config. If client config
+        * is not specified, it will be initialized to default values.
+        */
+        OpsWorksCMClient(const Aws::Client::ClientConfiguration& clientConfiguration);
+
+       /**
+        * Initializes client to use SimpleAWSCredentialsProvider, with default http client factory, and optional client config. If client config
+        * is not specified, it will be initialized to default values.
+        */
+        OpsWorksCMClient(const Aws::Auth::AWSCredentials& credentials,
+                         const Aws::Client::ClientConfiguration& clientConfiguration);
+
+       /**
+        * Initializes client to use specified credentials provider with specified client config. If http client factory is not supplied,
+        * the default http client factory will be used
+        */
+        OpsWorksCMClient(const std::shared_ptr<Aws::Auth::AWSCredentialsProvider>& credentialsProvider,
+                         const Aws::Client::ClientConfiguration& clientConfiguration);
+
+        /* End of legacy constructors due deprecation */
         virtual ~OpsWorksCMClient();
 
-
         /**
          * <p> Associates a new node with the server. For more information about how to
          * disassociate a node, see <a>DisassociateNode</a>.</p> <p> On a Chef server: This
@@ -114,12 +145,20 @@ namespace OpsWorksCM
         /**
          * A Callable wrapper for AssociateNode that returns a future to the operation so that it can be executed in parallel to other requests.
          */
-        virtual Model::AssociateNodeOutcomeCallable AssociateNodeCallable(const Model::AssociateNodeRequest& request) const;
+        template<typename AssociateNodeRequestT = Model::AssociateNodeRequest>
+        Model::AssociateNodeOutcomeCallable AssociateNodeCallable(const AssociateNodeRequestT& request) const
+        {
+            return SubmitCallable(&OpsWorksCMClient::AssociateNode, request);
+        }
 
         /**
          * An Async wrapper for AssociateNode that queues the request into a thread executor and triggers associated callback when operation has finished.
          */
-        virtual void AssociateNodeAsync(const Model::AssociateNodeRequest& request, const AssociateNodeResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
+        template<typename AssociateNodeRequestT = Model::AssociateNodeRequest>
+        void AssociateNodeAsync(const AssociateNodeRequestT& request, const AssociateNodeResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const
+        {
+            return SubmitAsync(&OpsWorksCMClient::AssociateNode, request, handler, context);
+        }
 
         /**
          * <p> Creates an application-level backup of a server. While the server is in the
@@ -142,12 +181,20 @@ namespace OpsWorksCM
         /**
          * A Callable wrapper for CreateBackup that returns a future to the operation so that it can be executed in parallel to other requests.
          */
-        virtual Model::CreateBackupOutcomeCallable CreateBackupCallable(const Model::CreateBackupRequest& request) const;
+        template<typename CreateBackupRequestT = Model::CreateBackupRequest>
+        Model::CreateBackupOutcomeCallable CreateBackupCallable(const CreateBackupRequestT& request) const
+        {
+            return SubmitCallable(&OpsWorksCMClient::CreateBackup, request);
+        }
 
         /**
          * An Async wrapper for CreateBackup that queues the request into a thread executor and triggers associated callback when operation has finished.
          */
-        virtual void CreateBackupAsync(const Model::CreateBackupRequest& request, const CreateBackupResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
+        template<typename CreateBackupRequestT = Model::CreateBackupRequest>
+        void CreateBackupAsync(const CreateBackupRequestT& request, const CreateBackupResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const
+        {
+            return SubmitAsync(&OpsWorksCMClient::CreateBackup, request, handler, context);
+        }
 
         /**
          * <p> Creates and immedately starts a new server. The server is ready to use when
@@ -182,12 +229,20 @@ namespace OpsWorksCM
         /**
          * A Callable wrapper for CreateServer that returns a future to the operation so that it can be executed in parallel to other requests.
          */
-        virtual Model::CreateServerOutcomeCallable CreateServerCallable(const Model::CreateServerRequest& request) const;
+        template<typename CreateServerRequestT = Model::CreateServerRequest>
+        Model::CreateServerOutcomeCallable CreateServerCallable(const CreateServerRequestT& request) const
+        {
+            return SubmitCallable(&OpsWorksCMClient::CreateServer, request);
+        }
 
         /**
          * An Async wrapper for CreateServer that queues the request into a thread executor and triggers associated callback when operation has finished.
          */
-        virtual void CreateServerAsync(const Model::CreateServerRequest& request, const CreateServerResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
+        template<typename CreateServerRequestT = Model::CreateServerRequest>
+        void CreateServerAsync(const CreateServerRequestT& request, const CreateServerResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const
+        {
+            return SubmitAsync(&OpsWorksCMClient::CreateServer, request, handler, context);
+        }
 
         /**
          * <p> Deletes a backup. You can delete both manual and automated backups. This
@@ -204,12 +259,20 @@ namespace OpsWorksCM
         /**
          * A Callable wrapper for DeleteBackup that returns a future to the operation so that it can be executed in parallel to other requests.
          */
-        virtual Model::DeleteBackupOutcomeCallable DeleteBackupCallable(const Model::DeleteBackupRequest& request) const;
+        template<typename DeleteBackupRequestT = Model::DeleteBackupRequest>
+        Model::DeleteBackupOutcomeCallable DeleteBackupCallable(const DeleteBackupRequestT& request) const
+        {
+            return SubmitCallable(&OpsWorksCMClient::DeleteBackup, request);
+        }
 
         /**
          * An Async wrapper for DeleteBackup that queues the request into a thread executor and triggers associated callback when operation has finished.
          */
-        virtual void DeleteBackupAsync(const Model::DeleteBackupRequest& request, const DeleteBackupResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
+        template<typename DeleteBackupRequestT = Model::DeleteBackupRequest>
+        void DeleteBackupAsync(const DeleteBackupRequestT& request, const DeleteBackupResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const
+        {
+            return SubmitAsync(&OpsWorksCMClient::DeleteBackup, request, handler, context);
+        }
 
         /**
          * <p> Deletes the server and the underlying AWS CloudFormation stacks (including
@@ -230,12 +293,20 @@ namespace OpsWorksCM
         /**
          * A Callable wrapper for DeleteServer that returns a future to the operation so that it can be executed in parallel to other requests.
          */
-        virtual Model::DeleteServerOutcomeCallable DeleteServerCallable(const Model::DeleteServerRequest& request) const;
+        template<typename DeleteServerRequestT = Model::DeleteServerRequest>
+        Model::DeleteServerOutcomeCallable DeleteServerCallable(const DeleteServerRequestT& request) const
+        {
+            return SubmitCallable(&OpsWorksCMClient::DeleteServer, request);
+        }
 
         /**
          * An Async wrapper for DeleteServer that queues the request into a thread executor and triggers associated callback when operation has finished.
          */
-        virtual void DeleteServerAsync(const Model::DeleteServerRequest& request, const DeleteServerResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
+        template<typename DeleteServerRequestT = Model::DeleteServerRequest>
+        void DeleteServerAsync(const DeleteServerRequestT& request, const DeleteServerResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const
+        {
+            return SubmitAsync(&OpsWorksCMClient::DeleteServer, request, handler, context);
+        }
 
         /**
          * <p> Describes your OpsWorks-CM account attributes. </p> <p> This operation is
@@ -243,17 +314,25 @@ namespace OpsWorksCM
          * href="http://docs.aws.amazon.com/goto/WebAPI/opsworkscm-2016-11-01/DescribeAccountAttributes">AWS
          * API Reference</a></p>
          */
-        virtual Model::DescribeAccountAttributesOutcome DescribeAccountAttributes(const Model::DescribeAccountAttributesRequest& request) const;
+        virtual Model::DescribeAccountAttributesOutcome DescribeAccountAttributes(const Model::DescribeAccountAttributesRequest& request = {}) const;
 
         /**
          * A Callable wrapper for DescribeAccountAttributes that returns a future to the operation so that it can be executed in parallel to other requests.
          */
-        virtual Model::DescribeAccountAttributesOutcomeCallable DescribeAccountAttributesCallable(const Model::DescribeAccountAttributesRequest& request) const;
+        template<typename DescribeAccountAttributesRequestT = Model::DescribeAccountAttributesRequest>
+        Model::DescribeAccountAttributesOutcomeCallable DescribeAccountAttributesCallable(const DescribeAccountAttributesRequestT& request = {}) const
+        {
+            return SubmitCallable(&OpsWorksCMClient::DescribeAccountAttributes, request);
+        }
 
         /**
          * An Async wrapper for DescribeAccountAttributes that queues the request into a thread executor and triggers associated callback when operation has finished.
          */
-        virtual void DescribeAccountAttributesAsync(const Model::DescribeAccountAttributesRequest& request, const DescribeAccountAttributesResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
+        template<typename DescribeAccountAttributesRequestT = Model::DescribeAccountAttributesRequest>
+        void DescribeAccountAttributesAsync(const DescribeAccountAttributesResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr, const DescribeAccountAttributesRequestT& request = {}) const
+        {
+            return SubmitAsync(&OpsWorksCMClient::DescribeAccountAttributes, request, handler, context);
+        }
 
         /**
          * <p> Describes backups. The results are ordered by time, with newest backups
@@ -265,17 +344,25 @@ namespace OpsWorksCM
          * href="http://docs.aws.amazon.com/goto/WebAPI/opsworkscm-2016-11-01/DescribeBackups">AWS
          * API Reference</a></p>
          */
-        virtual Model::DescribeBackupsOutcome DescribeBackups(const Model::DescribeBackupsRequest& request) const;
+        virtual Model::DescribeBackupsOutcome DescribeBackups(const Model::DescribeBackupsRequest& request = {}) const;
 
         /**
          * A Callable wrapper for DescribeBackups that returns a future to the operation so that it can be executed in parallel to other requests.
          */
-        virtual Model::DescribeBackupsOutcomeCallable DescribeBackupsCallable(const Model::DescribeBackupsRequest& request) const;
+        template<typename DescribeBackupsRequestT = Model::DescribeBackupsRequest>
+        Model::DescribeBackupsOutcomeCallable DescribeBackupsCallable(const DescribeBackupsRequestT& request = {}) const
+        {
+            return SubmitCallable(&OpsWorksCMClient::DescribeBackups, request);
+        }
 
         /**
          * An Async wrapper for DescribeBackups that queues the request into a thread executor and triggers associated callback when operation has finished.
          */
-        virtual void DescribeBackupsAsync(const Model::DescribeBackupsRequest& request, const DescribeBackupsResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
+        template<typename DescribeBackupsRequestT = Model::DescribeBackupsRequest>
+        void DescribeBackupsAsync(const DescribeBackupsResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr, const DescribeBackupsRequestT& request = {}) const
+        {
+            return SubmitAsync(&OpsWorksCMClient::DescribeBackups, request, handler, context);
+        }
 
         /**
          * <p> Describes events for a specified server. Results are ordered by time, with
@@ -291,12 +378,20 @@ namespace OpsWorksCM
         /**
          * A Callable wrapper for DescribeEvents that returns a future to the operation so that it can be executed in parallel to other requests.
          */
-        virtual Model::DescribeEventsOutcomeCallable DescribeEventsCallable(const Model::DescribeEventsRequest& request) const;
+        template<typename DescribeEventsRequestT = Model::DescribeEventsRequest>
+        Model::DescribeEventsOutcomeCallable DescribeEventsCallable(const DescribeEventsRequestT& request) const
+        {
+            return SubmitCallable(&OpsWorksCMClient::DescribeEvents, request);
+        }
 
         /**
          * An Async wrapper for DescribeEvents that queues the request into a thread executor and triggers associated callback when operation has finished.
          */
-        virtual void DescribeEventsAsync(const Model::DescribeEventsRequest& request, const DescribeEventsResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
+        template<typename DescribeEventsRequestT = Model::DescribeEventsRequest>
+        void DescribeEventsAsync(const DescribeEventsRequestT& request, const DescribeEventsResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const
+        {
+            return SubmitAsync(&OpsWorksCMClient::DescribeEvents, request, handler, context);
+        }
 
         /**
          * <p> Returns the current status of an existing association or disassociation
@@ -312,12 +407,20 @@ namespace OpsWorksCM
         /**
          * A Callable wrapper for DescribeNodeAssociationStatus that returns a future to the operation so that it can be executed in parallel to other requests.
          */
-        virtual Model::DescribeNodeAssociationStatusOutcomeCallable DescribeNodeAssociationStatusCallable(const Model::DescribeNodeAssociationStatusRequest& request) const;
+        template<typename DescribeNodeAssociationStatusRequestT = Model::DescribeNodeAssociationStatusRequest>
+        Model::DescribeNodeAssociationStatusOutcomeCallable DescribeNodeAssociationStatusCallable(const DescribeNodeAssociationStatusRequestT& request) const
+        {
+            return SubmitCallable(&OpsWorksCMClient::DescribeNodeAssociationStatus, request);
+        }
 
         /**
          * An Async wrapper for DescribeNodeAssociationStatus that queues the request into a thread executor and triggers associated callback when operation has finished.
          */
-        virtual void DescribeNodeAssociationStatusAsync(const Model::DescribeNodeAssociationStatusRequest& request, const DescribeNodeAssociationStatusResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
+        template<typename DescribeNodeAssociationStatusRequestT = Model::DescribeNodeAssociationStatusRequest>
+        void DescribeNodeAssociationStatusAsync(const DescribeNodeAssociationStatusRequestT& request, const DescribeNodeAssociationStatusResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const
+        {
+            return SubmitAsync(&OpsWorksCMClient::DescribeNodeAssociationStatus, request, handler, context);
+        }
 
         /**
          * <p> Lists all configuration management servers that are identified with your
@@ -329,17 +432,25 @@ namespace OpsWorksCM
          * href="http://docs.aws.amazon.com/goto/WebAPI/opsworkscm-2016-11-01/DescribeServers">AWS
          * API Reference</a></p>
          */
-        virtual Model::DescribeServersOutcome DescribeServers(const Model::DescribeServersRequest& request) const;
+        virtual Model::DescribeServersOutcome DescribeServers(const Model::DescribeServersRequest& request = {}) const;
 
         /**
          * A Callable wrapper for DescribeServers that returns a future to the operation so that it can be executed in parallel to other requests.
          */
-        virtual Model::DescribeServersOutcomeCallable DescribeServersCallable(const Model::DescribeServersRequest& request) const;
+        template<typename DescribeServersRequestT = Model::DescribeServersRequest>
+        Model::DescribeServersOutcomeCallable DescribeServersCallable(const DescribeServersRequestT& request = {}) const
+        {
+            return SubmitCallable(&OpsWorksCMClient::DescribeServers, request);
+        }
 
         /**
          * An Async wrapper for DescribeServers that queues the request into a thread executor and triggers associated callback when operation has finished.
          */
-        virtual void DescribeServersAsync(const Model::DescribeServersRequest& request, const DescribeServersResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
+        template<typename DescribeServersRequestT = Model::DescribeServersRequest>
+        void DescribeServersAsync(const DescribeServersResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr, const DescribeServersRequestT& request = {}) const
+        {
+            return SubmitAsync(&OpsWorksCMClient::DescribeServers, request, handler, context);
+        }
 
         /**
          * <p> Disassociates a node from an AWS OpsWorks CM server, and removes the node
@@ -359,12 +470,20 @@ namespace OpsWorksCM
         /**
          * A Callable wrapper for DisassociateNode that returns a future to the operation so that it can be executed in parallel to other requests.
          */
-        virtual Model::DisassociateNodeOutcomeCallable DisassociateNodeCallable(const Model::DisassociateNodeRequest& request) const;
+        template<typename DisassociateNodeRequestT = Model::DisassociateNodeRequest>
+        Model::DisassociateNodeOutcomeCallable DisassociateNodeCallable(const DisassociateNodeRequestT& request) const
+        {
+            return SubmitCallable(&OpsWorksCMClient::DisassociateNode, request);
+        }
 
         /**
          * An Async wrapper for DisassociateNode that queues the request into a thread executor and triggers associated callback when operation has finished.
          */
-        virtual void DisassociateNodeAsync(const Model::DisassociateNodeRequest& request, const DisassociateNodeResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
+        template<typename DisassociateNodeRequestT = Model::DisassociateNodeRequest>
+        void DisassociateNodeAsync(const DisassociateNodeRequestT& request, const DisassociateNodeResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const
+        {
+            return SubmitAsync(&OpsWorksCMClient::DisassociateNode, request, handler, context);
+        }
 
         /**
          * <p> Exports a specified server engine attribute as a base64-encoded string. For
@@ -383,12 +502,20 @@ namespace OpsWorksCM
         /**
          * A Callable wrapper for ExportServerEngineAttribute that returns a future to the operation so that it can be executed in parallel to other requests.
          */
-        virtual Model::ExportServerEngineAttributeOutcomeCallable ExportServerEngineAttributeCallable(const Model::ExportServerEngineAttributeRequest& request) const;
+        template<typename ExportServerEngineAttributeRequestT = Model::ExportServerEngineAttributeRequest>
+        Model::ExportServerEngineAttributeOutcomeCallable ExportServerEngineAttributeCallable(const ExportServerEngineAttributeRequestT& request) const
+        {
+            return SubmitCallable(&OpsWorksCMClient::ExportServerEngineAttribute, request);
+        }
 
         /**
          * An Async wrapper for ExportServerEngineAttribute that queues the request into a thread executor and triggers associated callback when operation has finished.
          */
-        virtual void ExportServerEngineAttributeAsync(const Model::ExportServerEngineAttributeRequest& request, const ExportServerEngineAttributeResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
+        template<typename ExportServerEngineAttributeRequestT = Model::ExportServerEngineAttributeRequest>
+        void ExportServerEngineAttributeAsync(const ExportServerEngineAttributeRequestT& request, const ExportServerEngineAttributeResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const
+        {
+            return SubmitAsync(&OpsWorksCMClient::ExportServerEngineAttribute, request, handler, context);
+        }
 
         /**
          * <p>Returns a list of tags that are applied to the specified AWS OpsWorks for
@@ -402,12 +529,20 @@ namespace OpsWorksCM
         /**
          * A Callable wrapper for ListTagsForResource that returns a future to the operation so that it can be executed in parallel to other requests.
          */
-        virtual Model::ListTagsForResourceOutcomeCallable ListTagsForResourceCallable(const Model::ListTagsForResourceRequest& request) const;
+        template<typename ListTagsForResourceRequestT = Model::ListTagsForResourceRequest>
+        Model::ListTagsForResourceOutcomeCallable ListTagsForResourceCallable(const ListTagsForResourceRequestT& request) const
+        {
+            return SubmitCallable(&OpsWorksCMClient::ListTagsForResource, request);
+        }
 
         /**
          * An Async wrapper for ListTagsForResource that queues the request into a thread executor and triggers associated callback when operation has finished.
          */
-        virtual void ListTagsForResourceAsync(const Model::ListTagsForResourceRequest& request, const ListTagsForResourceResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
+        template<typename ListTagsForResourceRequestT = Model::ListTagsForResourceRequest>
+        void ListTagsForResourceAsync(const ListTagsForResourceRequestT& request, const ListTagsForResourceResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const
+        {
+            return SubmitAsync(&OpsWorksCMClient::ListTagsForResource, request, handler, context);
+        }
 
         /**
          * <p> Restores a backup to a server that is in a <code>CONNECTION_LOST</code>,
@@ -433,12 +568,20 @@ namespace OpsWorksCM
         /**
          * A Callable wrapper for RestoreServer that returns a future to the operation so that it can be executed in parallel to other requests.
          */
-        virtual Model::RestoreServerOutcomeCallable RestoreServerCallable(const Model::RestoreServerRequest& request) const;
+        template<typename RestoreServerRequestT = Model::RestoreServerRequest>
+        Model::RestoreServerOutcomeCallable RestoreServerCallable(const RestoreServerRequestT& request) const
+        {
+            return SubmitCallable(&OpsWorksCMClient::RestoreServer, request);
+        }
 
         /**
          * An Async wrapper for RestoreServer that queues the request into a thread executor and triggers associated callback when operation has finished.
          */
-        virtual void RestoreServerAsync(const Model::RestoreServerRequest& request, const RestoreServerResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
+        template<typename RestoreServerRequestT = Model::RestoreServerRequest>
+        void RestoreServerAsync(const RestoreServerRequestT& request, const RestoreServerResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const
+        {
+            return SubmitAsync(&OpsWorksCMClient::RestoreServer, request, handler, context);
+        }
 
         /**
          * <p> Manually starts server maintenance. This command can be useful if an earlier
@@ -458,12 +601,20 @@ namespace OpsWorksCM
         /**
          * A Callable wrapper for StartMaintenance that returns a future to the operation so that it can be executed in parallel to other requests.
          */
-        virtual Model::StartMaintenanceOutcomeCallable StartMaintenanceCallable(const Model::StartMaintenanceRequest& request) const;
+        template<typename StartMaintenanceRequestT = Model::StartMaintenanceRequest>
+        Model::StartMaintenanceOutcomeCallable StartMaintenanceCallable(const StartMaintenanceRequestT& request) const
+        {
+            return SubmitCallable(&OpsWorksCMClient::StartMaintenance, request);
+        }
 
         /**
          * An Async wrapper for StartMaintenance that queues the request into a thread executor and triggers associated callback when operation has finished.
          */
-        virtual void StartMaintenanceAsync(const Model::StartMaintenanceRequest& request, const StartMaintenanceResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
+        template<typename StartMaintenanceRequestT = Model::StartMaintenanceRequest>
+        void StartMaintenanceAsync(const StartMaintenanceRequestT& request, const StartMaintenanceResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const
+        {
+            return SubmitAsync(&OpsWorksCMClient::StartMaintenance, request, handler, context);
+        }
 
         /**
          * <p>Applies tags to an AWS OpsWorks for Chef Automate or AWS OpsWorks for Puppet
@@ -476,12 +627,20 @@ namespace OpsWorksCM
         /**
          * A Callable wrapper for TagResource that returns a future to the operation so that it can be executed in parallel to other requests.
          */
-        virtual Model::TagResourceOutcomeCallable TagResourceCallable(const Model::TagResourceRequest& request) const;
+        template<typename TagResourceRequestT = Model::TagResourceRequest>
+        Model::TagResourceOutcomeCallable TagResourceCallable(const TagResourceRequestT& request) const
+        {
+            return SubmitCallable(&OpsWorksCMClient::TagResource, request);
+        }
 
         /**
          * An Async wrapper for TagResource that queues the request into a thread executor and triggers associated callback when operation has finished.
          */
-        virtual void TagResourceAsync(const Model::TagResourceRequest& request, const TagResourceResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
+        template<typename TagResourceRequestT = Model::TagResourceRequest>
+        void TagResourceAsync(const TagResourceRequestT& request, const TagResourceResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const
+        {
+            return SubmitAsync(&OpsWorksCMClient::TagResource, request, handler, context);
+        }
 
         /**
          * <p>Removes specified tags from an AWS OpsWorks-CM server or
@@ -494,12 +653,20 @@ namespace OpsWorksCM
         /**
          * A Callable wrapper for UntagResource that returns a future to the operation so that it can be executed in parallel to other requests.
          */
-        virtual Model::UntagResourceOutcomeCallable UntagResourceCallable(const Model::UntagResourceRequest& request) const;
+        template<typename UntagResourceRequestT = Model::UntagResourceRequest>
+        Model::UntagResourceOutcomeCallable UntagResourceCallable(const UntagResourceRequestT& request) const
+        {
+            return SubmitCallable(&OpsWorksCMClient::UntagResource, request);
+        }
 
         /**
          * An Async wrapper for UntagResource that queues the request into a thread executor and triggers associated callback when operation has finished.
          */
-        virtual void UntagResourceAsync(const Model::UntagResourceRequest& request, const UntagResourceResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
+        template<typename UntagResourceRequestT = Model::UntagResourceRequest>
+        void UntagResourceAsync(const UntagResourceRequestT& request, const UntagResourceResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const
+        {
+            return SubmitAsync(&OpsWorksCMClient::UntagResource, request, handler, context);
+        }
 
         /**
          * <p> Updates settings for a server. </p> <p> This operation is synchronous.
@@ -512,12 +679,20 @@ namespace OpsWorksCM
         /**
          * A Callable wrapper for UpdateServer that returns a future to the operation so that it can be executed in parallel to other requests.
          */
-        virtual Model::UpdateServerOutcomeCallable UpdateServerCallable(const Model::UpdateServerRequest& request) const;
+        template<typename UpdateServerRequestT = Model::UpdateServerRequest>
+        Model::UpdateServerOutcomeCallable UpdateServerCallable(const UpdateServerRequestT& request) const
+        {
+            return SubmitCallable(&OpsWorksCMClient::UpdateServer, request);
+        }
 
         /**
          * An Async wrapper for UpdateServer that queues the request into a thread executor and triggers associated callback when operation has finished.
          */
-        virtual void UpdateServerAsync(const Model::UpdateServerRequest& request, const UpdateServerResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
+        template<typename UpdateServerRequestT = Model::UpdateServerRequest>
+        void UpdateServerAsync(const UpdateServerRequestT& request, const UpdateServerResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const
+        {
+            return SubmitAsync(&OpsWorksCMClient::UpdateServer, request, handler, context);
+        }
 
         /**
          * <p> Updates engine-specific attributes on a specified server. The server enters
@@ -539,21 +714,30 @@ namespace OpsWorksCM
         /**
          * A Callable wrapper for UpdateServerEngineAttributes that returns a future to the operation so that it can be executed in parallel to other requests.
          */
-        virtual Model::UpdateServerEngineAttributesOutcomeCallable UpdateServerEngineAttributesCallable(const Model::UpdateServerEngineAttributesRequest& request) const;
+        template<typename UpdateServerEngineAttributesRequestT = Model::UpdateServerEngineAttributesRequest>
+        Model::UpdateServerEngineAttributesOutcomeCallable UpdateServerEngineAttributesCallable(const UpdateServerEngineAttributesRequestT& request) const
+        {
+            return SubmitCallable(&OpsWorksCMClient::UpdateServerEngineAttributes, request);
+        }
 
         /**
          * An Async wrapper for UpdateServerEngineAttributes that queues the request into a thread executor and triggers associated callback when operation has finished.
          */
-        virtual void UpdateServerEngineAttributesAsync(const Model::UpdateServerEngineAttributesRequest& request, const UpdateServerEngineAttributesResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const;
+        template<typename UpdateServerEngineAttributesRequestT = Model::UpdateServerEngineAttributesRequest>
+        void UpdateServerEngineAttributesAsync(const UpdateServerEngineAttributesRequestT& request, const UpdateServerEngineAttributesResponseReceivedHandler& handler, const std::shared_ptr<const Aws::Client::AsyncCallerContext>& context = nullptr) const
+        {
+            return SubmitAsync(&OpsWorksCMClient::UpdateServerEngineAttributes, request, handler, context);
+        }
 
 
       void OverrideEndpoint(const Aws::String& endpoint);
+      std::shared_ptr<OpsWorksCMEndpointProviderBase>& accessEndpointProvider();
     private:
-      void init(const Aws::Client::ClientConfiguration& clientConfiguration);
+      friend class Aws::Client::ClientWithAsyncTemplateMethods<OpsWorksCMClient>;
+      void init(const OpsWorksCMClientConfiguration& clientConfiguration);
 
-      Aws::String m_uri;
-      Aws::String m_configScheme;
-      std::shared_ptr<Aws::Utils::Threading::Executor> m_executor;
+      OpsWorksCMClientConfiguration m_clientConfiguration;
+      std::shared_ptr<OpsWorksCMEndpointProviderBase> m_endpointProvider;
   };
 
 } // namespace OpsWorksCM
