@@ -28,7 +28,7 @@ namespace Model
   class DescribeAccountSubscriptionResult
   {
   public:
-    AWS_QUICKSIGHT_API DescribeAccountSubscriptionResult();
+    AWS_QUICKSIGHT_API DescribeAccountSubscriptionResult() = default;
     AWS_QUICKSIGHT_API DescribeAccountSubscriptionResult(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);
     AWS_QUICKSIGHT_API DescribeAccountSubscriptionResult& operator=(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);
 
@@ -42,39 +42,40 @@ namespace Model
      * <p>The authentication type of the Amazon QuickSight account.</p> </li> <li>
      * <p>The status of the Amazon QuickSight account's subscription.</p> </li> </ul>
      */
-    inline const AccountInfo& GetAccountInfo() const{ return m_accountInfo; }
-    inline void SetAccountInfo(const AccountInfo& value) { m_accountInfo = value; }
-    inline void SetAccountInfo(AccountInfo&& value) { m_accountInfo = std::move(value); }
-    inline DescribeAccountSubscriptionResult& WithAccountInfo(const AccountInfo& value) { SetAccountInfo(value); return *this;}
-    inline DescribeAccountSubscriptionResult& WithAccountInfo(AccountInfo&& value) { SetAccountInfo(std::move(value)); return *this;}
+    inline const AccountInfo& GetAccountInfo() const { return m_accountInfo; }
+    template<typename AccountInfoT = AccountInfo>
+    void SetAccountInfo(AccountInfoT&& value) { m_accountInfoHasBeenSet = true; m_accountInfo = std::forward<AccountInfoT>(value); }
+    template<typename AccountInfoT = AccountInfo>
+    DescribeAccountSubscriptionResult& WithAccountInfo(AccountInfoT&& value) { SetAccountInfo(std::forward<AccountInfoT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The HTTP status of the request.</p>
      */
-    inline int GetStatus() const{ return m_status; }
-    inline void SetStatus(int value) { m_status = value; }
+    inline int GetStatus() const { return m_status; }
+    inline void SetStatus(int value) { m_statusHasBeenSet = true; m_status = value; }
     inline DescribeAccountSubscriptionResult& WithStatus(int value) { SetStatus(value); return *this;}
     ///@}
 
     ///@{
     
-    inline const Aws::String& GetRequestId() const{ return m_requestId; }
-    inline void SetRequestId(const Aws::String& value) { m_requestId = value; }
-    inline void SetRequestId(Aws::String&& value) { m_requestId = std::move(value); }
-    inline void SetRequestId(const char* value) { m_requestId.assign(value); }
-    inline DescribeAccountSubscriptionResult& WithRequestId(const Aws::String& value) { SetRequestId(value); return *this;}
-    inline DescribeAccountSubscriptionResult& WithRequestId(Aws::String&& value) { SetRequestId(std::move(value)); return *this;}
-    inline DescribeAccountSubscriptionResult& WithRequestId(const char* value) { SetRequestId(value); return *this;}
+    inline const Aws::String& GetRequestId() const { return m_requestId; }
+    template<typename RequestIdT = Aws::String>
+    void SetRequestId(RequestIdT&& value) { m_requestIdHasBeenSet = true; m_requestId = std::forward<RequestIdT>(value); }
+    template<typename RequestIdT = Aws::String>
+    DescribeAccountSubscriptionResult& WithRequestId(RequestIdT&& value) { SetRequestId(std::forward<RequestIdT>(value)); return *this;}
     ///@}
   private:
 
     AccountInfo m_accountInfo;
+    bool m_accountInfoHasBeenSet = false;
 
-    int m_status;
+    int m_status{0};
+    bool m_statusHasBeenSet = false;
 
     Aws::String m_requestId;
+    bool m_requestIdHasBeenSet = false;
   };
 
 } // namespace Model
